@@ -5,6 +5,7 @@ from .Alert import Alert
 from .Anchor import Anchor
 from .Avatar import Avatar
 from .AvatarGroup import AvatarGroup
+from .BackgroundImage import BackgroundImage
 from .Badge import Badge
 from .Blockquote import Blockquote
 from .Breadcrumbs import Breadcrumbs
@@ -12,6 +13,7 @@ from .Button import Button
 from .Center import Center
 from .Checkbox import Checkbox
 from .Chips import Chips
+from .Code import Code
 from .Col import Col
 from .ColorPicker import ColorPicker
 from .Container import Container
@@ -27,6 +29,8 @@ from .Image import Image
 from .InputWrapper import InputWrapper
 from .JsonInput import JsonInput
 from .Kbd import Kbd
+from .List import List
+from .ListItem import ListItem
 from .Loader import Loader
 from .LoadingOverlay import LoadingOverlay
 from .MantineProvider import MantineProvider
@@ -75,6 +79,7 @@ __all__ = [
     "Anchor",
     "Avatar",
     "AvatarGroup",
+    "BackgroundImage",
     "Badge",
     "Blockquote",
     "Breadcrumbs",
@@ -82,6 +87,7 @@ __all__ = [
     "Center",
     "Checkbox",
     "Chips",
+    "Code",
     "Col",
     "ColorPicker",
     "Container",
@@ -97,6 +103,8 @@ __all__ = [
     "InputWrapper",
     "JsonInput",
     "Kbd",
+    "List",
+    "ListItem",
     "Loader",
     "LoadingOverlay",
     "MantineProvider",
